/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2010-2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _INPUT_DBUS_H
#define _INPUT_DBUS_H 1

#include "DBLog.h"
#include <dbus/dbus.h>
#include <poll.h>
#include <set>
#include <vector>
#include <string>
#include <sys/select.h>

/* Class to listen on the system DBus for udev signals that new input event
 * devices are available.  When they are available create an InputEvent
 * for that device.
 */
class InputDBus
{
public:
	InputDBus(DBLog *log);
	virtual ~InputDBus();

	void SetDB(DBLog *log) { delete Log; Log=log; }
	int ProcessEvents();
private:
	// setup as a filter
	static DBusHandlerResult HandleMessage(DBusConnection *conn,
		DBusMessage *msg, void *user_data)
	{
		return ((InputDBus*)user_data)->HandleMessage(conn, msg);
	}
	DBusHandlerResult HandleMessage(DBusConnection *conn, DBusMessage *msg);
	static dbus_bool_t AddWatch(DBusWatch *watch, void *data)
	{ return ((InputDBus*)data)->AddWatch(watch); }
	dbus_bool_t AddWatch(DBusWatch *watch);
	static void RemoveWatch(DBusWatch *watch, void *data)
	{ return ((InputDBus*)data)->RemoveWatch(watch); }
	void RemoveWatch(DBusWatch *watch);
	static void ToggleWatch(DBusWatch *watch, void *data)
	{ return ((InputDBus*)data)->ToggleWatch(watch); }
	void ToggleWatch(DBusWatch *watch);
	// true error, false no error, if there is an error print it and free it
	bool IsError(const std::string &msg);

	DBusConnection *Conn[2];
	DBusError Err;
	// PollSet and WatchSet entries must line up, always push/pop erase both
	std::vector<pollfd> PollSet;
	std::vector<DBusWatch*> WatchSet;

	DBLog *Log;
};

#endif // _INPUT_DBUS_H
