/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "StackWindow.h"
#include "MinuteMonitor.h"
#include <QDeclarativeContext>

#include <iostream>
using namespace std;

// NULL parent top level window, non-NULL stacked on that, but still set
// Window to be a top level window.
StackWindow::StackWindow(MinuteMonitor *view, QWidget *parent) :
	QWidget(parent, Qt::Window),
	View(view),
	Child(NULL)
{
	#ifdef QT_MAEMO5_LIB
	setAttribute(Qt::WA_Maemo5StackedWindow);
	#endif
	if(!parent)
	{
		#ifdef QT_MAEMO5_LIB
		// only set on the top level
		setAttribute(Qt::WA_Maemo5AutoOrientation, true);
		#endif
		// only one needs to reset the size
		connect(View, SIGNAL(Reloaded()), SLOT(Reloaded()));
	}

	// Should be the default for Maemo 5 top level windows, but probably
	// some interaction with QML makes it required.
	showMaximized();

	TakeView();
}

void StackWindow::PushStack()
{
	if(!Child)
	{
		Child=new StackWindow(View, this);
		connect(Child, SIGNAL(hidden()), SLOT(TakeView()));
	}
	Child->TakeView();
	Child->show();
}

void StackWindow::hideEvent(QHideEvent * event)
{
	QWidget::hideEvent(event);
	// don't take over the context unless it is really hidden
	if(!isVisible())
		hidden();
}

void StackWindow::resizeEvent(QResizeEvent *event)
{
	QWidget::resizeEvent(event);
	View->resize(size());
}

void StackWindow::TakeView()
{
	View->rootContext()->setContextProperty("windowStack", this);
	View->setParent(this);
	View->resize(size());
	View->show();
}

void StackWindow::Reloaded()
{
	// Reset the size each time QML is reloaded, it seems to loose it.
	View->resize(size());
}
