/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _STORE_H
#define _STORE_H

#include "DBMonitor.h"
#include <time.h>

// Uses the DBMonitor class to load the call log data then processes it.
class Store
{
public:
	Store();
	bool Open();
	void Close() { return DB.Close(); }
	const DBMonitor::LogType& DataSet() const { return DB.DataSet(); }

	// Set the store to the period which contains the given time,
	// and returns the start of that period.
	time_t SetPeriod(const time_t in_period);
	// Load the current period log entries.
	bool Load();
	// previous and next period that is
	bool LoadPrevious();
	bool LoadNext();

	// return a string representing the given time, just date
	std::string DateToString(time_t when) const;
	// return a string representing the given time, date and time
	std::string TimestampToString(time_t when) const;
	// return the time at the start of the period (start of that day)
	time_t PeriodStart() const { return PStart; }
	// return the time at the end of the period (end of that day)
	time_t PeriodStop() const {return PEnd; }

	// depending on the plan options available these vary slightly in
	// meaning,
	// Anytime, the minutes which count against the available plan time,
	// if incoming is free then it will by definition only include
	// outgoing minutes
	// Incoming, if incoming is free the incoming minutes otherwise 0
	// Evening, if evening/weekends are free those minutes
	// Free, minutes used with a contact marked as Free

	// time in minutes
	int AnytimeUsed() const { return Anytime; }
	int AnytimeAvailable() const
	{ return DB.GetMinutesAvailable() - Anytime; }
	int IncomingUsed() const { return Incoming; }
	int EveningUsed() const { return Evening; }
	int FreeUsed() const { return Free; }
	int VoIPUsed() const { return VoIP; }
	// convert to given seconds into a displayed HH:MM:SS form
	static std::string MinutesToString(int sec);

	bool GetIncomingFree() const { return DB.GetIncomingFree(); }
	bool GetNonprimeFree() const { return DB.GetNonprimeFree(); }

protected:
	DBMonitor DB;

private:
	// the time at the beginning of the day that it starts and
	// time at the end of the day that it stops
	time_t PStart, PEnd;
	// time in minutes, see above Get/Set call comments
	int Anytime, Incoming, Evening, Free, VoIP;
};

#endif // _STORE_H
