/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Store.h"
#include <string.h>
#include <time.h>
#include <iostream>

using namespace std;

int main(int argc, char **argv)
{
	Store store;
	if(!store.Open())
		return 1;
	if(argc==2)
	{
		if(!strcmp(argv[1], "--help"))
		{
			cerr << "Usage: " << argv[0]
				<< " [ --prev | MM-DD-YYYY ]\n";
			return 0;
		}
		if(!strcmp(argv[1], "--prev"))
		{
			// set to the previous month's period
			time_t t_sec=time(NULL);
			struct tm *t=localtime(&t_sec);
			// mid day to not worry about daylight saving time
			t->tm_hour=12;
			t->tm_mon-=1;
			t->tm_isdst=-1;
			store.SetPeriod(mktime(t));
		}
		else
		{
			// display the time period the specified day is part of
			struct tm t;
			memset(&t, 0, sizeof(t));
			char *next=strptime(argv[1], "%m-%d-%Y", &t);
			// NULL no conversion, *next not NULL means the full
			// string wasn't used
			if(!next || *next)
			{
				cerr << "time expected in MM-DD-YYYY\n";
				return 1;
			}
			store.SetPeriod(mktime(&t));
		}
	}
	store.Load();
	const DBMonitor::LogType &log=store.DataSet();
	cout << store.TimestampToString(store.PeriodStart()) << " to "
		<< store.TimestampToString(store.PeriodStop()) << endl;
	// it's anytime or metered as for calls which reduce the number of
	// minutes available
	cout << "Type\t\tMinutes\tRemaining\n";
	if(store.GetIncomingFree())
		cout << "Outgoing/Cost\t";
	else
		cout << "Anytime\t\t";
	cout << store.AnytimeUsed() << '\t' << store.AnytimeAvailable() << endl;

	if(store.GetNonprimeFree())
	{
		cout << (store.GetIncomingFree() ? "Out/Nonprime\t" :
			"Evening/Weekend\t")
			<< store.EveningUsed() << "\tUnlimited\n";
	}

	if(store.GetIncomingFree())
	{
		cout << "Incoming(Free)\t" << store.IncomingUsed()
			<< "\tUnlimited\n";
	}

	cout << "Free\t\t" << store.FreeUsed() << "\tUnlimited\n";
	
	cout << "VoIP\t\t" << store.VoIPUsed() << "\tUnlimited\n";

	int cell = store.AnytimeUsed() + store.IncomingUsed() +
		store.EveningUsed() + store.FreeUsed();
	cout << "Total: Calls " << log.size() << ", Minutes "
		<< cell+store.VoIPUsed() << " (Cell " << cell << ")\n";
	return 0;
}
