/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// QtQuick doesn't ship by default on N900 (and isn't required here)
//import QtQuick 1.0
import Qt 4.7
import MinuteMonitor 0.1

// Allow switching the call type.  This also partly hides the parent items,
// and cancels if that area is pressed.
Rectangle
{
	id: editType
	// which label data to view
	property variant model: null

	anchors.fill: parent
	property int margin: 2
	property color border_color: "#808080"
	property real font_size: 18

	// partly transparent to hide the parent items
	color: "#80000000"

	ListModel
	{
		id: typeModel
	}
	// model isn't available, wait until now to set the data
	function update()
	{
		if(model.type == CallType.CALL_VOIP) // VOIP
		{
			typeModel.append({"call_type": "VoIP"})
			listView.currentIndex=0
		}
		else
		{
			typeModel.append({"call_type": "Cost"})
			typeModel.append({"call_type": "Free"})
			listView.currentIndex=model.type
		}

		name.text=model.remote_name
		uid.text=model.remote_uid
	}
	// cancel anyplace outside dialog
	MouseArea
	{
		anchors.fill: parent
		onClicked: editType.destroy()
	}
	Rectangle
	{
		id: dialog_background
		color: "black"
		border.color: border_color
		border.width: margin
		radius: margin
		width: parent.width*3/4
		height: parent.height*3/4
		x: (parent.width - width)/2
		y: (parent.height - height) - radius
		clip: true

		Column
		{
			x: margin*5
			y: margin*5
			width: parent.width-2*margin*5
			id: dialog

			Text
			{
				id: name
				color: "white"
				font.pointSize: font_size*1.3
			}
			Text
			{
				id: uid
				color: "white"
			}
			Text
			{
				color: "#00c0ff"
				font.pointSize: font_size*1.3
			}

			// make a line to separate the areas
			Rectangle
			{
				width: parent.width+2*margin*5
				y: margin
				x: -margin*5
				height: margin
				color: border_color
			}
		}

		ListView
		{
			id: listView
			anchors.margins: margin
			anchors.top: dialog.bottom
			width: parent.width
			height: parent.height - y - 2*margin
			model: typeModel
			pressDelay: press_delay
			focus: true
			highlightMoveDuration: 1
			highlight: Rectangle { color: selected_color }
			delegate:
			Text
			{
				color: "white"
				text: call_type
				font.pointSize: font_size*3
				width: parent.width
				horizontalAlignment: Text.AlignHCenter
				MouseArea
				{
					anchors.fill: parent
					onPressed: listView.currentIndex=index
					onClicked:
					{
						select(index)
					}
					focus: listView.currentIndex==index
					Keys.onEnterPressed: select(index)
				}
			}
		}
	}
	function select(list_index)
	{
		dismiss.start()
		// give visual feedback
		if(listView.count==1) // VoIP
			listView.highlightItem.color = "green"
		else if(list_index==CallType.CALL_COST)
			listView.highlightItem.color = "red"
		else if(list_index==CallType.CALL_FREE)
			listView.highlightItem.color = "yellow"
		index_picked=list_index
	}
	property int index_picked: -1
	Timer
	{
		id: dismiss
		interval: 150
		onTriggered :
		{
			if(model.type != 2 && model.type != index_picked)
			{
				if(index_picked==CallType.CALL_COST)
				{
					store.RemoveFreeContact(
						model.remote_uid)
				}
				else // FREE
				{
					store.AddFreeContact(model.remote_uid)
				}
			}
			editType.destroy()
		}
	}
}
