/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// QtQuick doesn't ship by default on N900 (and isn't required here)
//import QtQuick 1.0
import Qt 4.7

Rectangle
{
	id: top
	width: 500
	height: 300
	property color status_color: "white";
	property color selected_color: "#4080df"
	property color divider_color: "#303050"
	property int press_delay: 140
	property real min_button_width: 160
	property int margin: 20

	// image names used in CallLabels.qml and will cache the final file
	// to avoid trying different paths each time the image is requested
	property string do_search: "do_search"
	property string image_in: do_search
	property string image_out: do_search
	property string image_both: do_search
	property string image_unknown: do_search

	color: "black"

	Component.onCompleted :
	{
		minuteMonitor.Settings.connect(function()
		{
			windowStack.PushStack()
			create("Settings.qml")
		})
		minuteMonitor.About.connect(function()
		{
			windowStack.PushStack()
			create("About.qml")
		})
		/* Just for debugging.
		store.CallLog()
		create("CallLabels.qml")
		*/
	}


	MaemoButton
	{
		id: prev
		text: "Previous"
		anchors.bottom: status.top
		anchors.left: status.left
		width: min_button_width > label_width ? min_button_width
			: label_width
		onClicked : store.LoadPrevious()
	}
	MaemoButton
	{
		id: next
		text: "Next"
		anchors.bottom: status.top
		anchors.right: status.right
		width: min_button_width > label_width ? min_button_width
			: label_width
		onClicked : store.LoadNext()
	}

	Column
	{
		id: status
		anchors.centerIn: top
		spacing: 15

		Text { color: status_color;  text: store.statsHeader }
		Row
		{
			spacing: 25
			Text { color: status_color;  text: store.stats_1 }
			Text { color: status_color;  text: store.stats_2 }
			Text { color: status_color;  text: store.stats_3 }
		}
		Text { color: status_color;  text: store.statsFooter }
	}


	function popupLabels()
	{
		windowStack.PushStack()
		create("CallLabels.qml")
	}
	MaemoButton
	{
		id: call_log
		text: "call log"
		width: min_button_width > label_width ? min_button_width
			: label_width
		anchors.top: status.bottom
		anchors.left: status.left
		onClicked :
		{
			store.CallLog()
			popupLabels()
		}
	}
	MaemoButton
	{
		id: contact_log
		width: min_button_width > label_width ? min_button_width
			: label_width
		text: "contact log"
		anchors.top: status.bottom
		anchors.right: status.right
		onClicked :
		{
			store.ContactLog()
			popupLabels()
		}
	}
	function create(name, callback)
	{
		var component=Qt.createComponent(name)
		var complete=function()
		{
			if(component.status == Component.Ready)
			{
				var obj=component.createObject(top);
				if(callback)
					callback(obj);
			}
			else if(component.status == Component.NULL)
			{
				print("Error: component " + name +
					" status is NULL")
			}
			else if(component.status == Component.Error)
			{
				print("Error: component " + name + "\n" +
					component.errorString())
			}
		}
		if(component.status != Component.Loading)
		{
			complete()
		}
		else
		{
			component.statusChanged.connect(complete)
		}
	}
}
