/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// QtQuick doesn't ship by default on N900 (and isn't required here)
//import QtQuick 1.0
import Qt 4.7

Rectangle
{
	id: top

	property Flickable flickableItem

	property int min_size: 20
	property int hide_timeout: 500

	color: "#00a2ff"
	border.color: "white"
	border.width: 2
	radius: 2

	anchors.margins: 10 - width/2
	anchors.right: parent.right

	width: 5
	height:
	{
		var h=flickableItem.visibleArea.heightRatio*
			flickableItem.height;
		h > min_size ? h : min_size
	}
	y: flickableItem.visibleArea.yPosition * flickableItem.height

	opacity: .1
	states: State
	{
		name: "visible"
		when: flickableItem.moving
		PropertyChanges
		{
			target: top
			opacity: .4
		}
	}
	transitions: Transition
	{
		from: "visible"; to: ""
		NumberAnimation
		{
			properties: "opacity"
			duration: top.hide_timeout
		}
	}
}
