/* MinuteMonitor, log duration and display usage for the N900
 * Copyright (c) 2012 David Fries <David@Fries.net> http://david.fries.net/
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// QtQuick doesn't ship by default on N900 (and isn't required here)
//import QtQuick 1.0
import Qt 4.7

Rectangle
{
	id: settings
	anchors.fill: parent
	color: "black"
	// reminder, store is not available when constructed, don't bind
	// properties until onCompleted
	Component.onCompleted : 
	{
		// The Connections didn't seem to work, but this callback
		// does and gets called from the correct object.
		windowStack.hidden.connect(function()
		{
			settings.destroy()
		})
	}
	Grid
	{
		id: grid
		y: 10
		anchors.horizontalCenter: settings.horizontalCenter
		columns: 2
		spacing: 20
		Text
		{
			color: "white"
			horizontalAlignment: Text.AlignRight
			text: "Minutes per period: "
		}
		InputBox
		{
			id: minutesAvailable
			text: store.minutesAvailable
		}
		Text
		{
			color: "white"
			horizontalAlignment: Text.AlignRight
			text: "End of period (day): "
		}
		InputBox
		{
			id: periodEnd
			text: store.periodEnd
		}
		Text
		{
			color: "white"
			horizontalAlignment: Text.AlignRight
			text: "Weekday start: "
		}
		InputBox
		{
			// weekday starts (when the evening ends)
			id: eveningEnd
			text: store.eveningEnd
		}
		Text
		{
			color: "white"
			horizontalAlignment: Text.AlignRight
			text: "Weekday end: "
		}
		InputBox
		{
			// weekday ends (when the evening starts)
			id: eveningBegin
			text: store.eveningBegin
		}
		Text
		{
			id: incoming_label
			color: "white"
			horizontalAlignment: Text.AlignRight
			text: "Incoming free: "
		}
		CheckButton
		{
			id: incoming_free
			height: incoming_label.height*1.5
			checked: store.incomingFree
		}
		Text
		{
			id: nonprime_label
			color: "white"
			horizontalAlignment: Text.AlignRight
			text: "Evenings/Weekends free: "
		}
		CheckButton
		{
			id: nonprimeFree
			height: nonprime_label.height*1.5
			checked: store.nonprimeFree
		}
	}
	MaemoButton
	{
		id: save
		anchors.margins: margin
		anchors.top: grid.bottom
		anchors.left: grid.left
		text: "Save"
		onClicked :
		{
			store.minutesAvailable=minutesAvailable.text
			store.periodEnd=periodEnd.text
			store.eveningEnd=eveningEnd.text
			store.eveningBegin=eveningBegin.text
			store.incomingFree=incoming_free.checked
			store.nonprimeFree=nonprimeFree.checked
			store.WriteConfig()
		}
	}
	MaemoButton
	{
		id: contacts
		anchors.margins: margin
		anchors.top: grid.bottom
		anchors.right: grid.right
		text: "Telephone Contact List"
		onClicked :
		{
			store.LoadTelContacts()
			popupLabels()
		}
	}
}
